@@ -31,6 +31,8 @@
 #include <clutter/clutter.h>
 #include <clutter-gst/clutter-gst.h>
 #include <gst/gst.h>
+/* Avoid a warning. */
+#define GST_USE_UNSTABLE_API
 #include <gst/basecamerabinsrc/gstcamerabin-enum.h>
 #include <gst/pbutils/encoding-profile.h>
 #include <X11/Xlib.h>
@@ -188,10 +190,11 @@ static void
 cheese_camera_bus_message_cb (GstBus *bus, GstMessage *message, CheeseCamera *camera)
 {
   CheeseCameraPrivate *priv = cheese_camera_get_instance_private (camera);
+    GstMessageType type;
 
-  switch (GST_MESSAGE_TYPE (message))
-  {
-    case GST_MESSAGE_WARNING:
+    type = GST_MESSAGE_TYPE (message);
+
+    if (type == GST_MESSAGE_WARNING)
     {
       GError *err = NULL;
       gchar *debug = NULL;
@@ -205,9 +208,8 @@ cheese_camera_bus_message_cb (GstBus *bus, GstMessage *message, CheeseCamera *ca
       }
 
       g_free (debug);
-      break;
     }
-    case GST_MESSAGE_ERROR:
+    else if (type == GST_MESSAGE_ERROR)
     {
       GError *err = NULL;
       gchar *debug = NULL;
@@ -224,9 +226,8 @@ cheese_camera_bus_message_cb (GstBus *bus, GstMessage *message, CheeseCamera *ca
       g_signal_emit (camera, camera_signals[STATE_FLAGS_CHANGED], 0,
                      GST_STATE_NULL);
       g_free (debug);
-      break;
     }
-    case GST_MESSAGE_STATE_CHANGED:
+    else if (type == GST_MESSAGE_STATE_CHANGED)
     {
       if (strcmp (GST_MESSAGE_SRC_NAME (message), "camerabin") == 0)
       {
@@ -239,9 +240,8 @@ cheese_camera_bus_message_cb (GstBus *bus, GstMessage *message, CheeseCamera *ca
                                             priv->effect_pipeline_is_playing);
         }
       }
-      break;
     }
-    case GST_MESSAGE_ELEMENT:
+    else if (type == GST_MESSAGE_ELEMENT)
     {
       const GstStructure *structure;
       GstSample *sample;
@@ -284,13 +284,7 @@ cheese_camera_bus_message_cb (GstBus *bus, GstMessage *message, CheeseCamera *ca
           priv->is_recording = FALSE;
         }
       }
-      break;
     }
-    default:
-    {
-      break;
-    }
-  }
 }
 
 /*
@@ -1538,7 +1532,7 @@ static void
 cheese_camera_set_device_by_dev_uuid (CheeseCamera *camera, const gchar *uuid)
 {
     CheeseCameraPrivate *priv = cheese_camera_get_instance_private (camera);
-  gint                 i;
+    guint i;
 
   for (i = 0; i < priv->num_camera_devices; i++)
   {
